==> css-render-0.5.0.tgz: package/esm/src/mount.js <==
import { _ce, _qe, _re } from './utils';
/** get count of element */
function _gc(el) {
    const count = el.getAttribute('mount-count');
    if (count === null)
        return 0;
    return Number(count);
}
/** set count of element */
function _sc(el, count) {
    el.setAttribute('mount-count', String(count));
}
export { _gc, _sc };
/** unmount */
export function _u(intance, node, target) {
    const els = node.els;
    if (target === undefined) {
        els.forEach(_re);
        node.els = [];
    }
    else if (typeof target === 'string' || typeof target === 'number') {
        const targetElement = _qe(target);
        if (targetElement !== null && els.includes(targetElement)) {
            const mountCount = _gc(targetElement);
            if (mountCount === 1) {
                _re(targetElement);
                node.els = els.filter(el => el !== targetElement);
            }
            else {
                _sc(targetElement, mountCount - 1);
            }
        }
    }
    else if (els.includes(target)) {
        const mountCount = _gc(target);
        if (mountCount === 1) {
            _re(target);
            node.els = els.filter(el => el !== target);
        }
        else {
            _sc(target, mountCount - 1);
        }
    }
}
/** mount */
export function _m(instance, node, target, props) {
    let targetElement = null;
    if (target === undefined) {
        targetElement = document.createElement('style');
        document.head.appendChild(targetElement);
    }
    else if (typeof target === 'string' || typeof target === 'number') {
        targetElement = _qe(target);
        if (targetElement === null) {
            targetElement = _ce(target);
            document.head.appendChild(targetElement);
            _sc(targetElement, 1);
        }
        else {
            _sc(targetElement, _gc(targetElement) + 1);
            return targetElement;
        }
    }
    else {
        targetElement = target;
        const mountCount = _gc(targetElement);
        if (mountCount > 0) {
            _sc(targetElement, mountCount + 1);
            return target;
        }
    }
    const style = node.render(props);
    if (targetElement.innerHTML !== style) {
        targetElement.innerHTML = style;
    }
    return targetElement;
}

==> css-render-0.7.2.tgz: package/esm/src/mount.js <==
import { _ce, _qe, _re } from './utils';
/** get count of element */
function _gc(el) {
    const count = el.getAttribute('mount-count');
    if (count === null)
        return 0;
    return Number(count);
}
/** set count of element */
function _sc(el, count) {
    el.setAttribute('mount-count', String(count));
}
export { _gc, _sc };
/** unmount */
export function _u(intance, node, target) {
    const els = node.els;
    if (target === undefined) {
        els.forEach(_re);
        node.els = [];
    }
    else if (typeof target === 'string' || typeof target === 'number') {
        const targetElement = _qe(target);
        // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        if (targetElement && els.includes(targetElement)) {
            const mountCount = _gc(targetElement);
            if (mountCount === 1) {
                _re(targetElement);
                node.els = els.filter(el => el !== targetElement);
            }
            else {
                _sc(targetElement, mountCount - 1);
            }
        }
    }
    else if (els.includes(target)) {
        const mountCount = _gc(target);
        if (mountCount === 1) {
            _re(target);
            node.els = els.filter(el => el !== target);
        }
        else {
            _sc(target, mountCount - 1);
        }
    }
}
/** mount */
export function _m(instance, node, target, props) {
    let targetElement = null;
    if (target === undefined) {
        targetElement = document.createElement('style');
        document.head.appendChild(targetElement);
    }
    else if (typeof target === 'string' || typeof target === 'number') {
        targetElement = _qe(target);
        if (targetElement === null) {
            targetElement = _ce(target);
            document.head.appendChild(targetElement);
            _sc(targetElement, 1);
        }
        else {
            _sc(targetElement, _gc(targetElement) + 1);
            return targetElement;
        }
    }
    else {
        targetElement = target;
        const mountCount = _gc(targetElement);
        if (mountCount > 0) {
            _sc(targetElement, mountCount + 1);
            return target;
        }
    }
    const style = node.render(props);
    if (targetElement.innerHTML !== style) {
        targetElement.innerHTML = style;
    }
    return targetElement;
}
